=============
databroker-ls
=============

.. image:: https://img.shields.io/travis/claracoo/databroker-ls.svg
        :target: https://travis-ci.org/claracoo/databroker-ls

.. image:: https://img.shields.io/pypi/v/databroker-ls.svg
        :target: https://pypi.python.org/pypi/databroker-ls


listing option for databroker

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://claracoo.github.io/databroker-ls.

Features
--------

* TODO
